### Solo

All Types return a [ValueDict](https://github.com/cree-py/pynite/blob/master/docs/main.md#valuedict)

| Name | Description |
|------|-------------|
| solo.trn_rating | The Tracker Network Rating finishes. |
| solo.score | The Score finishes. |
| solo.top1 | The Victory Royales finishes. |
| solo.top3 | The number of Top 3 wins finishes. |
| solo.top5 | The number of Top 5 wins finishes. |
| solo.top6 | The number of Top 6 wins finishes. |
| solo.top10 | The number of Top 10 wins finishes. |
| solo.top12 | The number of Top 12 wins finishes. |
| solo.top25 | The number of Top 25 wins finishes. |
| solo.kd | The Kill to Death ratio in solos. |
| solo.matches | The number of matches played. |
| solo.kills | The number of kills the Player has.
| solo.minutes_played | The number of minutes the Player has played.
| solo.kpm | The average number of kills per minute. |
| solo.kpg | The average number of kills per game. |
| solo.avg_time_played | The average amount of time for each match. |
| solo.score_per_match | The average score per match played |
| solo.score_per_min | The average score per minute played |
